# LinguaNova

###Install
```python
pip install lingua-nova
```
###TODO

- [X] Tạo pip install 
- [ ] Tạo package structure gồm (utils, engine, dataloaders) # mới tạo có thể chưa cần code
- [ ] Thêm phần dataloaders cho một vài dataset của task text2speech, speech2text + requirements.txt
- [ ] Thêm phần metrics vào utils cho task t2p và p2t
- [ ] Thêm base Trainer, Validator, Predictor + requiremnts.txt + test
- [ ] TODO...